@@ -25,10 +25,11 @@ def main():
     parser.add_argument("-p", "--pdb", type=str, help="input PDB file",required=True)
     parser.add_argument("-s", "--shifts", type=str, help="input shifts file in NEF format",required=True)
     parser.add_argument("-l", "--lig", help=" include free ligands when computing flexibility", action="store_true")
-    parser.add_argument("-n", "--nonstd", help=" include non-standard residues when computing flexibility", action="store_true")
+    parser.add_argument("-n", "--nonstd", help="include non-standard residues when computing flexibility", action="store_true")
     parser.add_argument("-o", "--olig", help="combine chains into a single structure when calculating flexibility", action="store_true")
     parser.add_argument("-q", "--quiet", help="supress output to the terminal", action="store_true")
     parser.add_argument("-r", "--reref", help="re-reference shifts using PANAV before calculating RCI (requires Java)",action="store_true")
+    parser.add_argument("-w", "--welldef", help="compute ANSURR scores for only well-defined residues identified by CYRANGE", action="store_true")
     parser.add_argument("-v", "--version", action='version', version='\nANSURR | Accuracy of NMR Structures Using RCI and Rigidity v0.0.17 | citation: https://doi.org/10.1038/s41467-020-20177-1')
     args = parser.parse_args()
 
@@ -47,7 +48,7 @@ def main():
 
     if os.path.isdir(output_dir):
         shutil.rmtree(output_dir)
-        check_quiet_print(args.quiet,"overwriting output directory: "+output_dir)
+        check_quiet_print(args.quiet," -> overwriting output directory: "+output_dir)
     else:
         check_quiet_print(args.quiet," -> output directory: "+output_dir)
     os.makedirs(output_dir)  
@@ -113,11 +114,16 @@ def main():
                         compare.compare_rci_rigidity(rigidity,rci,output_dir+'/ANSURR_output/',quiet=args.quiet)  
 
 
-    check_quiet_print(args.quiet,"summary of ANSURR scores")
-    for line in open(output_dir+'/ANSURR_output/scores.out','r'):
-        check_quiet_print(args.quiet," -> "+line.strip())
+    if len(glob.glob(output_dir+'/ANSURR_output/out/*.out')) > 0:
+        if os.path.exists(output_dir+'/ANSURR_output/scores.out'):
+            check_quiet_print(args.quiet,"summary of ANSURR scores")
+            for line in open(output_dir+'/ANSURR_output/scores.out','r'):
+                check_quiet_print(args.quiet," -> "+line.strip())
+    else:
+        check_quiet_print(args.quiet," -> CRITICAL ERROR failed to calculate any validation scores, exiting")
+        sys.exit(1)
 
-    check_quiet_print(args.quiet,"\n")
+    check_quiet_print(args.quiet,"")
     sys.exit(0)
 
       
