@@ -42,6 +42,7 @@ class res(object):
         self.neighbours = ['',''] 
         self.assumed_RC = 0
         self.shift_types = ''
+        self.num_shifts = 0
         self.RCI = 0
         self.RCI_smoothed = 0
         
@@ -114,7 +115,7 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                 pass
 
     if len(cs_result_sets) == 0:
-        print(' -> no chemical shifts found, exiting')
+        check_quiet_print(quiet,' -> CRITICAL ERROR no chemical shifts found, exiting')
         sys.exit(1)
     else:
 
@@ -216,8 +217,8 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                         try:
                             resi = int(line[0].replace(' ','')[1:])
                             if line[1] != '      ' or line[2] != '      ' or line[3] != '      ' or line[4] != '      ' or line[5] != '      ' or line[6] != '      ': 
-                                for chemical_shift_set in enumerate(cs_result_sets):  
-                                    if panav_set_chain_offset[panav_output]["set"] == chemical_shift_set[0]+1:
+                                for s in cs_set._registry:  
+                                    if panav_set_chain_offset[panav_output]["set"] == s.i:
                                         for c in s.chains:                                               # iterate over different chains
                                             if panav_set_chain_offset[panav_output]["chain"] == c.i:
                                                 for r in c.residues:  
@@ -236,12 +237,12 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                 panav = False
 
         if panav:
-            for chemical_shift_set in enumerate(cs_result_sets):  
+            for s in cs_set._registry: 
                 for c in s.chains:                                               
                     for r in c.residues:  
                         r.shifts = r.reref_shifts
              
-        for chemical_shift_set in enumerate(cs_result_sets):  
+        for s in cs_set._registry: 
             for c in s.chains:                                               # iterate over different chains
                 for r in c.residues:                                                # append neighbours
                     for r2 in c.residues:                        
@@ -352,15 +353,18 @@ def calc_RCI(path_to_nef_file,output_dir='',panav=False,quiet=False):
                 else:
                     chains_output[c.i].append(output_dir+'RCI/'+os.path.basename(os.path.os.path.splitext(path_to_nef_file)[0])+"_"+c.i+"_"+str(s.i)+".rci")
 
-        msg=''
-        for s in valid_chains:
-            msg+= 'set '+str(s)+' [chain(s) '+valid_chains[s]+'], '
-        check_quiet_print(quiet,' -> found ' +str(len(valid_chains))+ ' set(s) of shifts - '+msg[:-2])
+        if len(glob.glob(output_dir+'RCI/'+os.path.basename(os.path.splitext(path_to_nef_file)[0])+"*.rci")) >0:
+            msg=''
+            for s in valid_chains:
+                msg+= 'set '+str(s)+' [chain(s) '+valid_chains[s]+'], '
+            check_quiet_print(quiet,' -> found ' +str(len(valid_chains))+ ' set(s) of shifts - '+msg[:-2])
+        else:
+            check_quiet_print(quiet,' -> CRITICAL ERROR RCI did not run successfully for any shifts file, exiting')
+            sys.exit(1)
 
     return chains_output
 
 
-
 def main():
 
     calc_RCI(sys.argv[1])
